@@ -28,13 +28,15 @@
 #include <DiscoverBackendsFactory.h>
 #include <resources/AbstractResourcesBackend.h>
 
-QVector<Category*> CategoriesReader::loadCategoriesFile(const QString& name)
+QVector<Category*> CategoriesReader::loadCategoriesFile(AbstractResourcesBackend* backend)
 {
     QVector<Category *> ret;
-    QString path = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("libdiscover/categories/")+name+QStringLiteral("-categories.xml"));
+    QString path = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("libdiscover/categories/")+backend->name()+QStringLiteral("-categories.xml"));
     if (path.isEmpty()) {
-        qWarning() << "Couldn't find a category for " << name;
-        return ret;
+        auto cat = backend->category();
+        if (cat.isEmpty())
+            qWarning() << "Couldn't find a category for " << backend->name();
+        return cat;
     }
     return loadCategoriesPath(path);
 }
@@ -69,28 +71,3 @@ QVector<Category*> CategoriesReader::loadCategoriesPath(const QString& path)
     }
     return ret;
 }
-
-bool CategoriesReader::categoryLessThan(Category *c1, const Category *c2)
-{
-    return (QString::localeAwareCompare(c1->name(), c2->name()) < 0);
-}
-
-QVector<Category*> CategoriesReader::populateCategories()
-{
-    DiscoverBackendsFactory f;
-    QStringList backendNames = f.allBackendNames();
-
-    QVector<Category*> ret;
-    Q_FOREACH (const QString& name, backendNames) {
-        const QVector<Category*> cats = loadCategoriesFile(name);
-
-        if(ret.isEmpty()) {
-            ret = cats;
-        } else {
-            Q_FOREACH (Category* c, cats)
-                Category::addSubcategory(ret, c);
-        }
-    }
-    qSort(ret.begin(), ret.end(), categoryLessThan);
-    return ret;
-}
