@@ -22,7 +22,6 @@
 
 #include <PackageKit/Daemon>
 #include <QDebug>
-#include <QMessageBox>
 #include <QAction>
 #include <QSet>
 
@@ -35,6 +34,7 @@ PackageKitUpdater::PackageKitUpdater(PackageKitBackend * parent)
     m_backend(parent),
     m_isCancelable(false),
     m_isProgressing(false),
+    m_status(PackageKit::Transaction::Status::StatusUnknown),
     m_speed(0),
     m_remainingTime(0),
     m_percentage(0),
@@ -60,6 +60,7 @@ void PackageKitUpdater::setupTransaction(PackageKit::Transaction::TransactionFla
     m_packagesRemoved.clear();
     m_transaction = PackageKit::Daemon::updatePackages(involvedPackages(m_toUpgrade).toList(), flags);
     m_isCancelable = m_transaction->allowCancel();
+    m_status = PackageKit::Transaction::Status::StatusUnknown;
 
     connect(m_transaction.data(), &PackageKit::Transaction::finished, this, &PackageKitUpdater::finished);
     connect(m_transaction.data(), &PackageKit::Transaction::package, this, &PackageKitUpdater::packageResolved);
@@ -107,6 +108,16 @@ QSet<QString> PackageKitUpdater::involvedPackages(const QSet<AbstractResource*>&
     return packageIds;
 }
 
+void PackageKitUpdater::proceed()
+{
+    if (!m_requiredEula.isEmpty()) {
+        PackageKit::Transaction* t = PackageKit::Daemon::acceptEula(m_requiredEula.takeFirst());
+        connect(t, &PackageKit::Transaction::finished, this, &PackageKitUpdater::start);
+        return;
+    }
+    setupTransaction(PackageKit::Transaction::TransactionFlagOnlyTrusted);
+}
+
 void PackageKitUpdater::start()
 {
     Q_ASSERT(!isProgressing());
@@ -127,11 +138,13 @@ void PackageKitUpdater::finished(PackageKit::Transaction::Exit exit, uint /*time
     m_transaction = nullptr;
 
     if (!cancel && simulate) {
-        int ret = m_packagesRemoved.isEmpty() ? QMessageBox::Yes : QMessageBox::question(nullptr, PackageKitMessages::statusMessage(PackageKit::Transaction::StatusRemove), PackageKitResource::joinPackages(m_packagesRemoved), QMessageBox::Yes, QMessageBox::No);
-        if (ret == QMessageBox::Yes) {
-            setupTransaction(PackageKit::Transaction::TransactionFlagOnlyTrusted);
-            return;
+        if (!m_packagesRemoved.isEmpty())
+            Q_EMIT proceedRequest(i18n("Packages to remove"), i18n("The following packages will be removed by the update:\n%1", PackageKitResource::joinPackages(m_packagesRemoved)));
+        else {
+            Q_ASSERT(m_requiredEula.isEmpty());
+            proceed();
         }
+        return;
     }
 
     setProgressing(false);
@@ -253,12 +266,14 @@ quint64 PackageKitUpdater::downloadSpeed() const
 
 void PackageKitUpdater::cancel()
 {
-    m_transaction->cancel();
+    if (m_transaction)
+        m_transaction->cancel();
+    else
+        setProgressing(false);
 }
 
 void PackageKitUpdater::errorFound(PackageKit::Transaction::Error err, const QString& error)
 {
-    Q_UNUSED(error);
     if (err == PackageKit::Transaction::ErrorNoLicenseAgreement)
         return;
     Q_EMIT passiveMessage(QStringLiteral("%1\n%2").arg(PackageKitMessages::errorMessage(err), error));
@@ -283,15 +298,9 @@ void PackageKitUpdater::requireRestart(PackageKit::Transaction::Restart restart,
 
 void PackageKitUpdater::eulaRequired(const QString& eulaID, const QString& packageID, const QString& vendor, const QString& licenseAgreement)
 {
-    QString packageName = PackageKit::Daemon::packageName(packageID);
-    int ret = QMessageBox::question(nullptr, i18n("%1 requires user to accept its license", packageName), i18n("The package %1 and its vendor %2 require that you accept their license:\n %3",
-                                                 packageName, vendor, licenseAgreement), QMessageBox::Yes, QMessageBox::No);
-    if (ret == QMessageBox::Yes) {
-        PackageKit::Transaction* t = PackageKit::Daemon::acceptEula(eulaID);
-        connect(t, &PackageKit::Transaction::finished, this, &PackageKitUpdater::start);
-    } else {
-        finished(PackageKit::Transaction::ExitCancelled, 0);
-    }
+    m_requiredEula += eulaID;
+    Q_EMIT proceedRequest(i18n("Accept EULA"), i18n("The package %1 and its vendor %2 require that you accept their license:\n %3",
+                                                 PackageKit::Daemon::packageName(packageID), vendor, licenseAgreement));
 }
 
 void PackageKitUpdater::setProgressing(bool progressing)
